==> IBRtools_0.1.2.tar.gz: IBRtools/README.md <==
# IBRtools 
<img src="hexlogo/r-ibr-logo.png" width = "300">

# 
#### The IBRtools package calculates two important indexes IBR (Integrated Biomarker Response) and IBRv2 (Integrated Biological Response version 2), it also calculates the intermediate values for enzyme activity for each index, and it has a graphing function to perform radarplots that make great data visualization for this type of data!
#
#
## How to install
```r
# install.packages("devtools")
# library(devtools)
Sys.setenv("R_REMOTES_NO_ERRORS_FROM_WARNINGS"=TRUE) #this is so warnings don't turn into errors
devtools::install_github("ecologicaltools/IBRtools")
library(IBRtools)

```
#
## 2) Downloading the zip version from this repository
####  Code -> Download zip -> Unzip it in your computer and open the directory IBRtools -> run the code devtools::install() -> update the packages as requested 
#
## 3) "It's still not working"

<!-- badges: start -->
[![R-CMD-check](https://github.com/ecologicaltools/IBRtools/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/ecologicaltools/IBRtools/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->
# 
#### Don't worry, it might be a version problem. You could simply create a free account in RStudio Cloud
(*The simpler is just use it in Rstudio Cloud and then export the files you want to save in your computer later on*)
#
#### If you still come across a new issue, please report it so we can fix it ASAP.
#
## Thanks for using our functions, don't forget to cite!

==> IBRtools_0.1.3.tar.gz: IBRtools/README.md <==
# IBRtools 
<img src="hexlogo/r-ibr-logo.png" width = "300">

# 
#### The IBRtools package calculates two important indexes IBR (Integrated Biomarker Response) and IBRv2 (Integrated Biological Response version 2), it also calculates the intermediate values for enzyme activity for each index, and it has a graphing function to perform radarplots that make great data visualization for this type of data!
#
#
## How to install
```r
# install.packages("devtools")
# library(devtools)
Sys.setenv("R_REMOTES_NO_ERRORS_FROM_WARNINGS"=TRUE) #this is so warnings don't turn into errors
devtools::install_github("ecologicaltools/IBRtools")
library(IBRtools)

```
#
## 2) Downloading the zip version from this repository
####  Code -> Download zip -> Unzip it in your computer and open the directory IBRtools -> run the code devtools::install() -> update the packages as requested 
#
## 3) "It's still not working"

<!-- badges: start -->
[![R-CMD-check](https://github.com/ecologicaltools/IBRtools/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/ecologicaltools/IBRtools/actions/workflows/R-CMD-check.yaml)
[![Codecov test coverage](https://codecov.io/gh/ecologicaltools/IBRtools/branch/main/graph/badge.svg)](https://app.codecov.io/gh/ecologicaltools/IBRtools?branch=main)
<!-- badges: end -->
# 
#### Don't worry, it might be a version problem. You could simply create a free account in RStudio Cloud
(*The simpler is just use it in Rstudio Cloud and then export the files you want to save in your computer later on*)
#
#### If you still come across a new issue, please report it so we can fix it ASAP.
#
## Thanks for using our functions, don't forget to cite!
